# Neosync Python SDK

This is the Python SDK for the Neosync API.

## Installation

```bash
pip install neosync
```

For more details and examples, see the [docs](https://docs.neosync.dev/api/python).
